"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var side_effect_js_1 = require("../side-effect-js");
describe('SideEffectJS - Load function tests', function () {
    beforeEach(function () {
        side_effect_js_1.default.Reset();
    });
    it('Should load 3 side effects', function () {
        var sideEffects = [
            side_effect_js_1.default.CreateEffect('id1', function () { }, function () { }),
            side_effect_js_1.default.CreateEffect('id2', function () { }, function () { }),
            side_effect_js_1.default.CreateEffect('id3', function () { }, function () { }),
        ];
        side_effect_js_1.default.Load(sideEffects);
        var allEffects = side_effect_js_1.default.GetAllEffects();
        expect(allEffects.length).toBe(sideEffects.length);
    });
    it('Should throw when loading effects with the same id', function () {
        var duplicateId = 'duplicate-id';
        var sideEffects = [
            side_effect_js_1.default.CreateEffect(duplicateId, function () { }, function () { }),
            side_effect_js_1.default.CreateEffect(duplicateId, function () { }, function () { })
        ];
        expect(function () { return side_effect_js_1.default.Load(sideEffects); }).toThrow("side-effect-js: load failed, Found duplicate id in effects:" + duplicateId);
    });
});
describe('SideEffectJS - UseSimulator tests', function () {
    beforeEach(function () {
        side_effect_js_1.default.Reset();
    });
    it('Should return the simulate value and not the real value when using UseSimulator', function () {
        var fakeValue = "this-is-fake";
        var realValue = "this-is-real";
        var sideEffects = [
            side_effect_js_1.default.CreateEffect('effect1', function () { return realValue; }, function () { return fakeValue; })
        ];
        side_effect_js_1.default.Load(sideEffects);
        side_effect_js_1.default.UseSimulator();
        var returnedValue = side_effect_js_1.default.Get('effect1')();
        expect(returnedValue).toEqual(fakeValue);
    });
    it('Should return the real value and not the fake value when not using UseSimulator', function () {
        var fakeValue = "this-is-fake";
        var realValue = "this-is-real";
        var sideEffects = [
            side_effect_js_1.default.CreateEffect('effect1', function () { return realValue; }, function () { return fakeValue; })
        ];
        side_effect_js_1.default.Load(sideEffects);
        var returnedValue = side_effect_js_1.default.Get('effect1')();
        expect(returnedValue).toEqual(realValue);
    });
});
